@@ -1,7 +1,7 @@
 """
 aiohttp JSON-RPC server integration.
 """
-
+from typing import Any, Optional
 from aiohttp import web
 
 import pjrpc
@@ -16,14 +16,14 @@ class Application:
     :param kwargs: arguments to be passed to the dispatcher :py:class:`pjrpc.server.AsyncDispatcher`
     """
 
-    def __init__(self, path='', app=None, **kwargs):
+    def __init__(self, path: str = '', app: Optional[web.Application] = None, **kwargs: Any):
         self._app = app or web.Application()
         self._dispatcher = pjrpc.server.AsyncDispatcher(**kwargs)
 
         self._app.router.add_post(path, self.rpc_handle)
 
     @property
-    def app(self):
+    def app(self) -> web.Application:
         """
         aiohttp application.
         """
@@ -31,14 +31,14 @@ class Application:
         return self._app
 
     @property
-    def dispatcher(self):
+    def dispatcher(self) -> pjrpc.server.Dispatcher:
         """
         JSON-RPC method dispatcher.
         """
 
         return self._dispatcher
 
-    async def rpc_handle(self, http_request):
+    async def rpc_handle(self, http_request: web.Request) -> web.Response:
         """
         Handles JSON-RPC request.
 
